@@ -1,9 +1,14 @@
 #' Download STATS19 data for a year
 #'
 #' @section Details:
-#' This function downloads and unzips UK road crash data.
-#' It results in unzipped .csv files that are put
-#' in the temporary directory specified by `get_data_directory()` or provided `data_dir`.
+#' This function downloads UK road crash data.
+#' It results in .csv files that are put
+#' in a directory that can be set with [get_data_directory()].
+#' By default, stats19 downloads files to a temporary directory.
+#' You can change this behavior to save the files in a permanent directory.
+#' This is done by setting the `STATS19_DOWNLOAD_DIRECTORY` environment variable.
+#' A convenient way to do this is by adding `STATS19_DOWNLOAD_DIRECTORY=/path/to/a/dir`
+#' to your `.Renviron` file, which can be opened with `usethis::edit_r_environ()`.
 #'
 #' The file downloaded would be for a specific year (e.g. 2022).
 #' It could also be a file containing data for a range of two (e.g. 2005-2014).
@@ -15,11 +20,11 @@
 #'
 #' @param file_name The file name (DfT named) to download.
 #' @param year A year matching file names on the STATS19
-#' [data release page](https://www.data.gov.uk/dataset/cb7ae6f0-4be6-4935-9277-47e5ce24a11f/road-safety-data)
+#' [data release page](https://www.data.gov.uk/dataset/cb7ae6f0-4be6-4935-9277-47e5ce24a11f/road-accidents-safety-data)
 #'  e.g. `2020`
 #' @param type One of 'collision', 'casualty', 'Vehicle'; defaults to 'collision'.
 #' This text string is used to match the file names released by the DfT.
-#' @param data_dir Parent directory for all downloaded files. Defaults to `tempdir()`.
+#' @param data_dir Parent directory for all downloaded files. See [get_data_directory()] for details.
 #' @param ask Should you be asked whether or not to download the files? `TRUE` by default.
 #' @param silent Boolean. If `FALSE` (default value), display useful progress
 #'   messages on the screen.
@@ -64,25 +69,24 @@ dl_stats19 = function(year = NULL,
         fnames = fnames[1]
       }
     }
-    zip_url = get_url(fnames)
+    file_url = get_url(fnames)
   } else {
     many_found = FALSE
     fnames = file_name
     nfiles_found = length(fnames)
-    zip_url = get_url(file_name = file_name)
+    file_url = get_url(file_name = file_name)
   }
 
   if (isFALSE(silent)) {
     message("Files identified: ", paste0(fnames, "\n"))
-    message(paste0("   ", zip_url, collapse = "\n"))
+    message(paste0("   ", file_url, collapse = "\n"))
   }
 
   if (!dir.exists(data_dir)) {
     dir.create(data_dir, recursive = TRUE)
   }
 
-  exdir = sub(".zip", "", fnames)
-  destfile = file.path(data_dir, paste0(exdir))
+  destfile = file.path(data_dir, fnames)
   data_already_exists = file.exists(destfile)
   if (data_already_exists) {
     if (isFALSE(silent)) {
@@ -95,7 +99,7 @@ dl_stats19 = function(year = NULL,
       } else {
         resp = ""
       }
-      if (resp != "" &
+      if (resp != "" &&
         !grepl(
           pattern = "yes|y",
           x = resp,
@@ -105,11 +109,12 @@ dl_stats19 = function(year = NULL,
       }
     }
     
-    res = curl::curl_fetch_disk(zip_url, destfile)
-    if (res$status != 200) {
-      message("Failed to download file: ", zip_url)
+    tryCatch({
+      curl::curl_download(file_url, destfile)
+    }, error = function(e) {
+      message("Failed to download file: ", file_url)
       return(NULL)
-    }
+    })
     if (isFALSE(silent)) {
       message("Data saved at ", destfile)
     }
