@@ -1,15 +1,22 @@
 #' Download, read and format STATS19 data in one function.
 #'
 #' @section Details:
-#' This function uses gets STATS19 data. Behind the scenes it uses
+#' This function gets STATS19 data. Behind the scenes it uses
 #' `dl_stats19()` and `read_*` functions, returning a
 #' `tibble` (default), `data.frame`, `sf` or `ppp` object, depending on the
 #' `output_format` parameter.
+#'
+#' By default, stats19 downloads files to a temporary directory.
+#' You can change this behavior to save the files in a permanent directory.
+#' This is done by setting the `STATS19_DOWNLOAD_DIRECTORY` environment variable.
+#' A convenient way to do this is by adding `STATS19_DOWNLOAD_DIRECTORY=/path/to/a/dir`
+#' to your `.Renviron` file, which can be opened with `usethis::edit_r_environ()`.
+#'
 #' The function returns data for a specific year (e.g. `year = 2022`)
 #'
 #' Note: for years before 2016 the function may return data from more years than are
 #' requested due to the nature of the files hosted at
-#' [data.gov.uk](https://www.data.gov.uk/dataset/cb7ae6f0-4be6-4935-9277-47e5ce24a11f/road-safety-data).
+#' [data.gov.uk](https://www.data.gov.uk/dataset/cb7ae6f0-4be6-4935-9277-47e5ce24a11f/road-accidents-safety-data).
 #'
 #' As this function uses `dl_stats19` function, it can download many MB of data,
 #' so ensure you have a sufficient disk space.
@@ -37,12 +44,18 @@
 #' \donttest{
 #' if(curl::has_internet()) {
 #' col = get_stats19(year = 2022, type = "collision")
-#' cas2 = get_stats19(year = 2022, type = "casualty")
+#' cas = get_stats19(year = 2022, type = "casualty")
 #' veh = get_stats19(year = 2022, type = "vehicle")
 #' class(col)
 #' # data.frame output
 #' x = get_stats19(2022, silent = TRUE, output_format = "data.frame")
 #' class(x)
+#' 
+#' # # Get 5-years worth of data (commented-out due to large response size):
+#' # col_5 = get_stats19(year = 5, type = "collision")
+#' # cas_5 = get_stats19(year = 5, type = "casualty")
+#' # veh_5 = get_stats19(year = 5, type = "vehicle")
+#' 
 #'
 #' # Run tests only if endpoint is alive:
 #' if(nrow(x) > 0) {
@@ -124,11 +137,6 @@ get_stats19 = function(year = NULL,
     output_format = "tibble"
   }
 
-  # Update year to 1979 if it's NULL or before 2018:
-  if (is.null(year) || year < 2018) {
-    year = 1979
-  }
-
   # download what the user wanted
   dl_stats19(year = year,
              type = type,
